---
sidebar_position: 6
---

# ResponseSynthesizer (СинтезаторВідповідей)

`Ця документація була автоматично перекладена і може містити помилки. Не соромтеся відкривати Pull Request, щоб запропонувати зміни.`

СинтезаторВідповідей відповідає за надсилання запиту, вузлів та шаблонів запитів до LLM для генерації відповіді. Є кілька ключових режимів для генерації відповіді:

- `Refine` (Вдосконалити): "створити та вдосконалити" відповідь, послідовно проходячи крізь кожен отриманий фрагмент тексту.
  Це здійснює окремий виклик LLM для кожного вузла. Добре підходить для детальних відповідей.
- `CompactAndRefine` (Компактно та вдосконалити) (за замовчуванням): "компактність" запиту під час кожного виклику LLM шляхом заповнення максимального розміру запиту якомога більшою кількістю фрагментів тексту. Якщо є
  забагато фрагментів для заповнення одного запиту, "створити та вдосконалити" відповідь, пройшовши через
  кілька компактних запитів. Те саме, що й `refine`, але повинно призвести до меншої кількості викликів LLM.
- `TreeSummarize` (ЗведенняДоДерева): Задано набір фрагментів тексту та запит, рекурсивно побудувати дерево
  та повернути кореневий вузол як відповідь. Добре підходить для стислого узагальнення.
- `SimpleResponseBuilder` (ПростийПобудовникВідповідей): Задано набір фрагментів тексту та запит, застосувати запит до кожного фрагменту тексту
  одночасно накопичуючи відповіді в масив. Повертає об'єднану рядок з усіх
  відповідей. Добре, коли потрібно окремо запустити один і той же запит проти кожного фрагменту тексту.

```typescript
import { NodeWithScore, ResponseSynthesizer, TextNode } from "llamaindex";

const responseSynthesizer = new ResponseSynthesizer();

const nodesWithScore: NodeWithScore[] = [
  {
    node: new TextNode({ text: "Мені 10 років." }),
    score: 1,
  },
  {
    node: new TextNode({ text: "Джону 20 років." }),
    score: 0.5,
  },
];

const response = await responseSynthesizer.synthesize(
  "Скільки мені років?",
  nodesWithScore,
);
console.log(response.response);
```

## Довідка по API

- [ResponseSynthesizer (СинтезаторВідповідей)](../../api/classes/ResponseSynthesizer.md)
- [Refine (Вдосконалити)](../../api/classes/Refine.md)
- [CompactAndRefine (Компактно та вдосконалити)](../../api/classes/CompactAndRefine.md)
- [TreeSummarize (ЗведенняДоДерева)](../../api/classes/TreeSummarize.md)
- [SimpleResponseBuilder (ПростийПобудовникВідповідей)](../../api/classes/SimpleResponseBuilder.md)

"
